/**
 * @file
 * Contains the definition of the OpenAgenda filters behaviour.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.openAgendaFilters = {
    attach: function (context) {
      // Load only once.
      if (context !== document) {
        return;
      }

      // window.oa.
      if (typeof window.oa === 'undefined') {
        window.oa = {
          query: window.location.search,
          locale: drupalSettings.openagenda.lang,
          locales: {
            en: {
              eventsTotal: '{total, plural, =0 {No events match this search} one {{total} event} other {{total} events}}'
            },
            fr: {
              eventsTotal: '{total, plural, =0 {Aucun événement ne correspond à cette recherche} one {{total} événement} other {{total} événements}}'
            }
          },
          res: drupalSettings.openagenda.filtersUrl,
          ajaxUrl: drupalSettings.openagenda.ajaxUrl,
          filtersRef: null,
          values: null,
          queryParams: null,
          onLoad: async (values, aggregations, filtersRef, _form) => {
            oa.filtersRef = filtersRef;
            oa.values = values;
            oa.queryParams = {...values, aggregations};

            // Update filters.
            await  oa.updateFiltersAndWidgets();
          },
          onFilterChange: async (values, aggregations, filtersRef, _form) => {
            oa.filtersRef = filtersRef;
            oa.values = values;
            oa.queryParams = {...values, aggregations};

            // Show Ajax Throbber, automatically removed when content is replaced/page reloaded.
            $('#oa-wrapper').append(Drupal.theme.ajaxProgressIndicatorFullscreen());

            // Load events.
            Drupal.ajax({
              url: oa.ajaxUrl + '?' + $.param(oa.queryParams)
            }).execute();

            // Update filters and location.
            oa.updateFiltersAndWidgets();
            oa.filtersRef.updateLocation(oa.values);
          },
          updateFiltersAndWidgets: async () => {

            $.ajax({
              url: oa.res + '?' + $.param(oa.queryParams),
              type: 'GET',
              dataType: 'json',
              async: true,
              complete: (data) => {
                oa.filtersRef.updateFiltersAndWidgets(oa.values, data.responseJSON);
              }
            });
          },
        };
      }
    }
  };
})(jQuery, Drupal, drupalSettings);
